/****************************************************************************
** Meta object code from reading C++ file 'SidebarMode.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../systemsettings-6.6.90/app/SidebarMode.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'SidebarMode.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN15FocusHackWidgetE_t {};
} // unnamed namespace

template <> constexpr inline auto FocusHackWidget::qt_create_metaobjectdata<qt_meta_tag_ZN15FocusHackWidgetE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "FocusHackWidget",
        "focusNext",
        "",
        "focusPrevious"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'focusNext'
        QtMocHelpers::SlotData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'focusPrevious'
        QtMocHelpers::SlotData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<FocusHackWidget, qt_meta_tag_ZN15FocusHackWidgetE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject FocusHackWidget::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15FocusHackWidgetE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15FocusHackWidgetE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN15FocusHackWidgetE_t>.metaTypes,
    nullptr
} };

void FocusHackWidget::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<FocusHackWidget *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->focusNext(); break;
        case 1: _t->focusPrevious(); break;
        default: ;
        }
    }
    (void)_a;
}

const QMetaObject *FocusHackWidget::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *FocusHackWidget::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15FocusHackWidgetE_t>.strings))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int FocusHackWidget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 2)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 2;
    }
    return _id;
}
namespace {
struct qt_meta_tag_ZN16SubcategoryModelE_t {};
} // unnamed namespace

template <> constexpr inline auto SubcategoryModel::qt_create_metaobjectdata<qt_meta_tag_ZN16SubcategoryModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "SubcategoryModel",
        "titleChanged",
        "",
        "iconChanged",
        "categoryOwnedByKCMChanged",
        "loadParentCategoryModule",
        "title",
        "icon",
        "QIcon",
        "categoryOwnedByKCM"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'titleChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'iconChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'categoryOwnedByKCMChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'loadParentCategoryModule'
        QtMocHelpers::MethodData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'title'
        QtMocHelpers::PropertyData<QString>(6, QMetaType::QString, QMC::DefaultPropertyFlags, 0),
        // property 'icon'
        QtMocHelpers::PropertyData<QIcon>(7, 0x80000000 | 8, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 1),
        // property 'categoryOwnedByKCM'
        QtMocHelpers::PropertyData<bool>(9, QMetaType::Bool, QMC::DefaultPropertyFlags, 2),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<SubcategoryModel, qt_meta_tag_ZN16SubcategoryModelE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject SubcategoryModel::staticMetaObject = { {
    QMetaObject::SuperData::link<KSelectionProxyModel::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16SubcategoryModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16SubcategoryModelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN16SubcategoryModelE_t>.metaTypes,
    nullptr
} };

void SubcategoryModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<SubcategoryModel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->titleChanged(); break;
        case 1: _t->iconChanged(); break;
        case 2: _t->categoryOwnedByKCMChanged(); break;
        case 3: _t->loadParentCategoryModule(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (SubcategoryModel::*)()>(_a, &SubcategoryModel::titleChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (SubcategoryModel::*)()>(_a, &SubcategoryModel::iconChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (SubcategoryModel::*)()>(_a, &SubcategoryModel::categoryOwnedByKCMChanged, 2))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->title(); break;
        case 1: *reinterpret_cast<QIcon*>(_v) = _t->icon(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->categoryOwnedByKCM(); break;
        default: break;
        }
    }
}

const QMetaObject *SubcategoryModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *SubcategoryModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16SubcategoryModelE_t>.strings))
        return static_cast<void*>(this);
    return KSelectionProxyModel::qt_metacast(_clname);
}

int SubcategoryModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KSelectionProxyModel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 4)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 4;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    return _id;
}

// SIGNAL 0
void SubcategoryModel::titleChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void SubcategoryModel::iconChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void SubcategoryModel::categoryOwnedByKCMChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}
namespace {
struct qt_meta_tag_ZN11SidebarModeE_t {};
} // unnamed namespace

template <> constexpr inline auto SidebarMode::qt_create_metaobjectdata<qt_meta_tag_ZN11SidebarModeE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "SidebarMode",
        "QML.Element",
        "auto",
        "QML.Creatable",
        "false",
        "QML.UncreatableReason",
        "Not creatable, use the systemsettings attached property",
        "activeCategoryRowChanged",
        "",
        "activeSubCategoryRowChanged",
        "activeSearchRowChanged",
        "widthChanged",
        "actionMenuVisibleChanged",
        "headerHeightChanged",
        "devicePixelRatioChanged",
        "defaultsIndicatorsVisibleChanged",
        "viewChanged",
        "state",
        "moduleLoaded",
        "updateDefaults",
        "initWidget",
        "giveFocus",
        "action",
        "QAction*",
        "name",
        "actionIconName",
        "const QAction*",
        "showActionMenu",
        "QPoint",
        "position",
        "loadModule",
        "QModelIndex",
        "activeModule",
        "args",
        "focusNext",
        "focusPrevious",
        "categoryModel",
        "QAbstractItemModel*",
        "searchModel",
        "subCategoryModel",
        "activeCategoryRow",
        "activeSearchRow",
        "activeSubCategoryRow",
        "width",
        "actionMenuVisible",
        "defaultsIndicatorsVisible",
        "headerHeight",
        "devicePixelRatio",
        "ApplicationMode",
        "SystemSettings",
        "InfoCenter"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'activeCategoryRowChanged'
        QtMocHelpers::SignalData<void()>(7, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'activeSubCategoryRowChanged'
        QtMocHelpers::SignalData<void()>(9, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'activeSearchRowChanged'
        QtMocHelpers::SignalData<void()>(10, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'widthChanged'
        QtMocHelpers::SignalData<void()>(11, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'actionMenuVisibleChanged'
        QtMocHelpers::SignalData<void()>(12, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'headerHeightChanged'
        QtMocHelpers::SignalData<void()>(13, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'devicePixelRatioChanged'
        QtMocHelpers::SignalData<void()>(14, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'defaultsIndicatorsVisibleChanged'
        QtMocHelpers::SignalData<void()>(15, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'viewChanged'
        QtMocHelpers::SignalData<void(bool)>(16, 8, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 17 },
        }}),
        // Slot 'moduleLoaded'
        QtMocHelpers::SlotData<void()>(18, 8, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateDefaults'
        QtMocHelpers::SlotData<void()>(19, 8, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'initWidget'
        QtMocHelpers::SlotData<void()>(20, 8, QMC::AccessPrivate, QMetaType::Void),
        // Method 'giveFocus'
        QtMocHelpers::MethodData<void()>(21, 8, QMC::AccessPublic, QMetaType::Void),
        // Method 'action'
        QtMocHelpers::MethodData<QAction *(const QString &) const>(22, 8, QMC::AccessPublic, 0x80000000 | 23, {{
            { QMetaType::QString, 24 },
        }}),
        // Method 'actionIconName'
        QtMocHelpers::MethodData<QString(const QString &) const>(25, 8, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QString, 24 },
        }}),
        // Method 'actionIconName'
        QtMocHelpers::MethodData<QString(const QAction *) const>(25, 8, QMC::AccessPublic, QMetaType::QString, {{
            { 0x80000000 | 26, 22 },
        }}),
        // Method 'showActionMenu'
        QtMocHelpers::MethodData<void(const QPoint &)>(27, 8, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 28, 29 },
        }}),
        // Method 'loadModule'
        QtMocHelpers::MethodData<void(const QModelIndex &, const QStringList &)>(30, 8, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 31, 32 }, { QMetaType::QStringList, 33 },
        }}),
        // Method 'loadModule'
        QtMocHelpers::MethodData<void(const QModelIndex &)>(30, 8, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 31, 32 },
        }}),
        // Method 'focusNext'
        QtMocHelpers::MethodData<void()>(34, 8, QMC::AccessPublic, QMetaType::Void),
        // Method 'focusPrevious'
        QtMocHelpers::MethodData<void()>(35, 8, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'categoryModel'
        QtMocHelpers::PropertyData<QAbstractItemModel*>(36, 0x80000000 | 37, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'searchModel'
        QtMocHelpers::PropertyData<QAbstractItemModel*>(38, 0x80000000 | 37, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'subCategoryModel'
        QtMocHelpers::PropertyData<QAbstractItemModel*>(39, 0x80000000 | 37, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'activeCategoryRow'
        QtMocHelpers::PropertyData<int>(40, QMetaType::Int, QMC::DefaultPropertyFlags, 0),
        // property 'activeSearchRow'
        QtMocHelpers::PropertyData<int>(41, QMetaType::Int, QMC::DefaultPropertyFlags, 2),
        // property 'activeSubCategoryRow'
        QtMocHelpers::PropertyData<int>(42, QMetaType::Int, QMC::DefaultPropertyFlags, 1),
        // property 'width'
        QtMocHelpers::PropertyData<int>(43, QMetaType::Int, QMC::DefaultPropertyFlags, 3),
        // property 'actionMenuVisible'
        QtMocHelpers::PropertyData<bool>(44, QMetaType::Bool, QMC::DefaultPropertyFlags, 4),
        // property 'defaultsIndicatorsVisible'
        QtMocHelpers::PropertyData<bool>(45, QMetaType::Bool, QMC::DefaultPropertyFlags, 7),
        // property 'headerHeight'
        QtMocHelpers::PropertyData<qreal>(46, QMetaType::QReal, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 5),
        // property 'devicePixelRatio'
        QtMocHelpers::PropertyData<qreal>(47, QMetaType::QReal, QMC::DefaultPropertyFlags, 6),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'ApplicationMode'
        QtMocHelpers::EnumData<enum ApplicationMode>(48, 48, QMC::EnumFlags{}).add({
            {   49, ApplicationMode::SystemSettings },
            {   50, ApplicationMode::InfoCenter },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
    });
    return QtMocHelpers::metaObjectData<SidebarMode, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject SidebarMode::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11SidebarModeE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11SidebarModeE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN11SidebarModeE_t>.metaTypes,
    nullptr
} };

void SidebarMode::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<SidebarMode *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->activeCategoryRowChanged(); break;
        case 1: _t->activeSubCategoryRowChanged(); break;
        case 2: _t->activeSearchRowChanged(); break;
        case 3: _t->widthChanged(); break;
        case 4: _t->actionMenuVisibleChanged(); break;
        case 5: _t->headerHeightChanged(); break;
        case 6: _t->devicePixelRatioChanged(); break;
        case 7: _t->defaultsIndicatorsVisibleChanged(); break;
        case 8: _t->viewChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 9: _t->moduleLoaded(); break;
        case 10: _t->updateDefaults(); break;
        case 11: _t->initWidget(); break;
        case 12: _t->giveFocus(); break;
        case 13: { QAction* _r = _t->action((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QAction**>(_a[0]) = std::move(_r); }  break;
        case 14: { QString _r = _t->actionIconName((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 15: { QString _r = _t->actionIconName((*reinterpret_cast<std::add_pointer_t<const QAction*>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 16: _t->showActionMenu((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1]))); break;
        case 17: _t->loadModule((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[2]))); break;
        case 18: _t->loadModule((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1]))); break;
        case 19: _t->focusNext(); break;
        case 20: _t->focusPrevious(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (SidebarMode::*)()>(_a, &SidebarMode::activeCategoryRowChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (SidebarMode::*)()>(_a, &SidebarMode::activeSubCategoryRowChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (SidebarMode::*)()>(_a, &SidebarMode::activeSearchRowChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (SidebarMode::*)()>(_a, &SidebarMode::widthChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (SidebarMode::*)()>(_a, &SidebarMode::actionMenuVisibleChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (SidebarMode::*)()>(_a, &SidebarMode::headerHeightChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (SidebarMode::*)()>(_a, &SidebarMode::devicePixelRatioChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (SidebarMode::*)()>(_a, &SidebarMode::defaultsIndicatorsVisibleChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (SidebarMode::*)(bool )>(_a, &SidebarMode::viewChanged, 8))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 2:
        case 1:
        case 0:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QAbstractItemModel* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QAbstractItemModel**>(_v) = _t->categoryModel(); break;
        case 1: *reinterpret_cast<QAbstractItemModel**>(_v) = _t->searchModel(); break;
        case 2: *reinterpret_cast<QAbstractItemModel**>(_v) = _t->subCategoryModel(); break;
        case 3: *reinterpret_cast<int*>(_v) = _t->activeCategoryRow(); break;
        case 4: *reinterpret_cast<int*>(_v) = _t->activeSearchRow(); break;
        case 5: *reinterpret_cast<int*>(_v) = _t->activeSubCategoryRow(); break;
        case 6: *reinterpret_cast<int*>(_v) = _t->width(); break;
        case 7: *reinterpret_cast<bool*>(_v) = _t->actionMenuVisible(); break;
        case 8: *reinterpret_cast<bool*>(_v) = _t->defaultsIndicatorsVisible(); break;
        case 9: *reinterpret_cast<qreal*>(_v) = _t->headerHeight(); break;
        case 10: *reinterpret_cast<qreal*>(_v) = _t->devicePixelRatio(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 9: _t->setHeaderHeight(*reinterpret_cast<qreal*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *SidebarMode::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *SidebarMode::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11SidebarModeE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int SidebarMode::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 21)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 21;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 21)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 21;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    }
    return _id;
}

// SIGNAL 0
void SidebarMode::activeCategoryRowChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void SidebarMode::activeSubCategoryRowChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void SidebarMode::activeSearchRowChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void SidebarMode::widthChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void SidebarMode::actionMenuVisibleChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void SidebarMode::headerHeightChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void SidebarMode::devicePixelRatioChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void SidebarMode::defaultsIndicatorsVisibleChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void SidebarMode::viewChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1);
}
QT_WARNING_POP
