/********************************************************************************
** Form generated from reading UI file 'externalModule.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_EXTERNALMODULE_H
#define UI_EXTERNALMODULE_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_ExternalModule
{
public:
    QVBoxLayout *verticalLayout;
    QSpacerItem *verticalSpacer;
    QHBoxLayout *horizontalLayout_2;
    QSpacerItem *horizontalSpacer;
    QLabel *LblText;
    QSpacerItem *horizontalSpacer_2;
    QHBoxLayout *horizontalLayout_3;
    QSpacerItem *horizontalSpacer_3;
    QPushButton *PbRelaunch;
    QSpacerItem *horizontalSpacer1;
    QSpacerItem *verticalSpacer1;

    void setupUi(QWidget *ExternalModule)
    {
        if (ExternalModule->objectName().isEmpty())
            ExternalModule->setObjectName("ExternalModule");
        ExternalModule->resize(400, 105);
        verticalLayout = new QVBoxLayout(ExternalModule);
        verticalLayout->setObjectName("verticalLayout");
        verticalSpacer = new QSpacerItem(0, 0, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        horizontalSpacer = new QSpacerItem(0, 0, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer);

        LblText = new QLabel(ExternalModule);
        LblText->setObjectName("LblText");
        LblText->setText(QString::fromUtf8("((PlaceholderText))"));
        LblText->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignVCenter);
        LblText->setWordWrap(true);

        horizontalLayout_2->addWidget(LblText);

        horizontalSpacer_2 = new QSpacerItem(0, 0, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer_2);


        verticalLayout->addLayout(horizontalLayout_2);

        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setObjectName("horizontalLayout_3");
        horizontalSpacer_3 = new QSpacerItem(0, 0, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_3->addItem(horizontalSpacer_3);

        PbRelaunch = new QPushButton(ExternalModule);
        PbRelaunch->setObjectName("PbRelaunch");
        QIcon icon(QIcon::fromTheme(QString::fromUtf8("system-run-symbolic")));
        PbRelaunch->setIcon(icon);

        horizontalLayout_3->addWidget(PbRelaunch);

        horizontalSpacer1 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_3->addItem(horizontalSpacer1);


        verticalLayout->addLayout(horizontalLayout_3);

        verticalSpacer1 = new QSpacerItem(0, 0, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer1);


        retranslateUi(ExternalModule);

        QMetaObject::connectSlotsByName(ExternalModule);
    } // setupUi

    void retranslateUi(QWidget *ExternalModule)
    {
        ExternalModule->setWindowTitle(tr2i18n("Dialog", nullptr));
        PbRelaunch->setText(QString());
    } // retranslateUi

};

namespace Ui {
    class ExternalModule: public Ui_ExternalModule {};
} // namespace Ui

QT_END_NAMESPACE

#endif // EXTERNALMODULE_H

