/****************************************************************************
** Meta object code from reading C++ file 'ModuleView.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../systemsettings-6.6.90/app/ModuleView.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'ModuleView.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN10ModuleViewE_t {};
} // unnamed namespace

template <> constexpr inline auto ModuleView::qt_create_metaobjectdata<qt_meta_tag_ZN10ModuleViewE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ModuleView",
        "moduleChanged",
        "",
        "state",
        "moduleSaved",
        "closeRequest",
        "showDefaultsIndicatorsChanged",
        "show",
        "loadModule",
        "QModelIndex",
        "menuItem",
        "args",
        "moduleHelp",
        "moduleLoad",
        "saveActiveModule",
        "moduleDefaults",
        "keyPressEvent",
        "QKeyEvent*",
        "event",
        "activeModuleChanged",
        "KPageWidgetItem*",
        "current",
        "previous",
        "stateChanged",
        "authStatusChanged",
        "KAuth::Action::AuthStatus",
        "status"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'moduleChanged'
        QtMocHelpers::SignalData<void(bool)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 3 },
        }}),
        // Signal 'moduleSaved'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'closeRequest'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'showDefaultsIndicatorsChanged'
        QtMocHelpers::SignalData<void(bool)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 7 },
        }}),
        // Slot 'loadModule'
        QtMocHelpers::SlotData<void(const QModelIndex &, const QStringList &)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 10 }, { QMetaType::QStringList, 11 },
        }}),
        // Slot 'moduleHelp'
        QtMocHelpers::SlotData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'moduleLoad'
        QtMocHelpers::SlotData<void()>(13, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'saveActiveModule'
        QtMocHelpers::SlotData<void()>(14, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'moduleDefaults'
        QtMocHelpers::SlotData<void()>(15, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'keyPressEvent'
        QtMocHelpers::SlotData<void(QKeyEvent *)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 17, 18 },
        }}),
        // Slot 'activeModuleChanged'
        QtMocHelpers::SlotData<void(KPageWidgetItem *, KPageWidgetItem *)>(19, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 20, 21 }, { 0x80000000 | 20, 22 },
        }}),
        // Slot 'stateChanged'
        QtMocHelpers::SlotData<void()>(23, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'authStatusChanged'
        QtMocHelpers::SlotData<void(KAuth::Action::AuthStatus)>(24, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 25, 26 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ModuleView, qt_meta_tag_ZN10ModuleViewE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject ModuleView::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10ModuleViewE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10ModuleViewE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN10ModuleViewE_t>.metaTypes,
    nullptr
} };

void ModuleView::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ModuleView *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->moduleChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 1: _t->moduleSaved(); break;
        case 2: _t->closeRequest(); break;
        case 3: _t->showDefaultsIndicatorsChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 4: _t->loadModule((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[2]))); break;
        case 5: _t->moduleHelp(); break;
        case 6: _t->moduleLoad(); break;
        case 7: _t->saveActiveModule(); break;
        case 8: _t->moduleDefaults(); break;
        case 9: _t->keyPressEvent((*reinterpret_cast<std::add_pointer_t<QKeyEvent*>>(_a[1]))); break;
        case 10: _t->activeModuleChanged((*reinterpret_cast<std::add_pointer_t<KPageWidgetItem*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KPageWidgetItem*>>(_a[2]))); break;
        case 11: _t->stateChanged(); break;
        case 12: _t->authStatusChanged((*reinterpret_cast<std::add_pointer_t<KAuth::Action::AuthStatus>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (ModuleView::*)(bool )>(_a, &ModuleView::moduleChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (ModuleView::*)()>(_a, &ModuleView::moduleSaved, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (ModuleView::*)()>(_a, &ModuleView::closeRequest, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (ModuleView::*)(bool )>(_a, &ModuleView::showDefaultsIndicatorsChanged, 3))
            return;
    }
}

const QMetaObject *ModuleView::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ModuleView::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10ModuleViewE_t>.strings))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int ModuleView::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 13)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 13;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 13)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 13;
    }
    return _id;
}

// SIGNAL 0
void ModuleView::moduleChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void ModuleView::moduleSaved()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void ModuleView::closeRequest()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void ModuleView::showDefaultsIndicatorsChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}
QT_WARNING_POP
