// This file was generated by ecm_qt_declare_logging_category(): DO NOT EDIT!

#include "systemsettings_app_debug.h"


Q_LOGGING_CATEGORY(SYSTEMSETTINGS_APP_LOG, "org.kde.systemsettings.app", QtInfoMsg)

